AtomicPtr

Struct AtomicPtr 

pub struct AtomicPtr<T>(/* private fields */);
Mock implementation of std::sync::atomic::AtomicPtr or portable_atomic::AtomicPtr.

Implementations

Source

impl<T> AtomicPtr<T>

pub fn new(v: *mut T) -> Self

Creates a new instance of AtomicPtr.

pub fn into_inner(self) -> *mut T

Consumes the atomic and returns the contained value.

pub fn load(&self, order: Ordering) -> *mut T

Loads a value from the pointer.

pub fn store(&self, val: *mut T, order: Ordering)

Stores a value into the pointer.

pub fn swap(&self, val: *mut T, order: Ordering) -> *mut T

Stores a value into the pointer, returning the previous value.

pub fn compare_exchange( &self, current: *mut T, new: *mut T, success: Ordering, failure: Ordering, ) -> Result<*mut T, *mut T>

Stores a value into the pointer if the current value is the same as the current value.

pub fn compare_exchange_weak( &self, current: *mut T, new: *mut T, success: Ordering, failure: Ordering, ) -> Result<*mut T, *mut T>

Stores a value into the atomic if the current value is the same as the current value.

pub fn fetch_update<F>( &self, set_order: Ordering, fetch_order: Ordering, f: F, ) -> Result<*mut T, *mut T>
where F: FnMut(*mut T) -> Option<*mut T>,

Fetches the value, and applies a function to it that returns an optional new value.