pub struct AtomicPtr<T>(/* private fields */);Expand description
Mock implementation of std::sync::atomic::AtomicPtr or portable_atomic::AtomicPtr.
Implementations
Sourceimpl<T> AtomicPtr<T>
impl<T> AtomicPtr<T>
Sourcepub fn into_inner(self) -> *mut T
pub fn into_inner(self) -> *mut T
Consumes the atomic and returns the contained value.
Sourcepub fn swap(&self, val: *mut T, order: Ordering) -> *mut T
pub fn swap(&self, val: *mut T, order: Ordering) -> *mut T
Stores a value into the pointer, returning the previous value.
Sourcepub fn compare_exchange(
&self,
current: *mut T,
new: *mut T,
success: Ordering,
failure: Ordering,
) -> Result<*mut T, *mut T>
pub fn compare_exchange( &self, current: *mut T, new: *mut T, success: Ordering, failure: Ordering, ) -> Result<*mut T, *mut T>
Stores a value into the pointer if the current value is the same as the current value.